import facebook

from models import FacebookConfig
from django.conf import settings
from django.core.mail import send_mail
from django.core.urlresolvers import reverse
from django.contrib.sites.models import Site

APP_ID = getattr(settings, 'FB_APP_ID')
APP_SECRET = getattr(settings, 'FB_APP_SECRET')

def _mail_admin(message):
    send_mail(u'FPW notification', message , getattr(settings, 'DEFAULT_FROM_EMAIL', None),
    [email[1] for email in getattr(settings, 'ADMINS', ((None, None),))], fail_silently=False)

def _get_token():
    conf, created = FacebookConfig.objects.get_or_create(app_id=APP_ID, app_secret=APP_SECRET)
    return conf.access_token

def _get_auth(init_token=''):
    if not init_token:
        token = _get_token()
    else:
        token = init_token
    if token:
        graph = facebook.GraphAPI(token)
        return graph
    else:
        site_id = getattr(settings, 'SITE_ID',1)
        current_site = Site.objects.get(id=site_id)
        _mail_admin(u'No active token, please login in http://%(site)s%(url)s' % {'site': current_site.domain, 'url': reverse('fblogin')})

def post(page_id, component, message, **kwargs):
    graph = _get_auth()
    if graph:
        page_access_token = graph.get_object(page_id, fields='access_token').get('access_token')
        if page_access_token:
            page_graph = _get_auth(page_access_token)
            result =  page_graph.put_object(page_id, component,message=message,**kwargs)
            if result.has_key('error'):
                _mail_admin(result['error']['message'])
    return None




from django.db import models

class FacebookConfig(models.Model):
    app_id = models.CharField(max_length=40)
    app_secret = models.CharField(max_length=120)
    access_token = models.CharField(max_length=255, blank=True, null=True)
    



from django.conf.urls import patterns, url

urlpatterns = patterns('',
                       url(r'', 'facebookpagewriter.views.fblogin', name='fblogin'),
                       )                      



import hashlib
import random
import string

from django.http import HttpResponseRedirect
from django.core.urlresolvers import reverse
from django.http import HttpResponse
from django.conf import settings
from django.contrib.sites.shortcuts import get_current_site
from facebook import get_access_token_from_code
from facebookpagewriter.models import FacebookConfig

APP_ID = getattr(settings, 'FB_APP_ID')
APP_SECRET = getattr(settings, 'FB_APP_SECRET')

def fblogin(request):
    current_site = get_current_site(request)
    if 'code' not in request.GET:
        state = hashlib.sha224(''.join(random.sample(string.printable,40))).hexdigest()
        dialog_url = "https://www.facebook.com/dialog/oauth?client_id=%(id)s&redirect_uri=http://%(site)s%(url)s&state=%(state)s&scope=publish_actions,status_update,publish_stream,manage_pages" % {'id':APP_ID,'state': state, 'url': reverse('fblogin'),'site':current_site.domain}
        return HttpResponseRedirect(dialog_url)
    else:
        code = request.GET['code']
        result = get_access_token_from_code(code, 'http://%(site)s%(url)s' % {'site': current_site.domain, 'url': reverse('fblogin')}, APP_ID, APP_SECRET)
        token = result.get('access_token','')
        config, created = FacebookConfig.objects.get_or_create(app_id=APP_ID,app_secret=APP_SECRET)
        config.access_token = token
        config.save()
        return HttpResponse('token: %(token)s'% {'token': token})



from setuptools import setup, find_packages
import sys, os

version = '0.6'

setup(
    name='facebookpagewriter',
    version=version,
    description='Automate Facebook page posting',
    long_description="",
    author='Aitzol Naberan',
    author_email='anaberan@codesyntax.com',
    url='http://github.com/codesyntax/facebookpagewriter',
    package_dir={'facebookpagewriter': 'facebookpagewriter'},
    packages=find_packages(exclude=['ez_setup','examples','tests']),
    include_package_data=True,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ],
)
